@@ -116,14 +116,12 @@ def django_to_cache(
         get_or_create_redis_model_from_django_model
 ):
     for django_instance in django_model.objects.all():
-
         redis_instance = update_or_create_redis_instance_from_django_instance(
             django_instance,
             redis_model,
             redis_root,
             get_or_create_redis_model_from_django_model
         )
-        print(django_instance)
 
 
 def update_or_create_redis_instance_from_django_instance(
@@ -138,7 +136,6 @@ def update_or_create_redis_instance_from_django_instance(
         redis_root,
         get_or_create_redis_model_from_django_model
     )
-    print(redis_dict)
 
     if not redis_instance:
         redis_model(
@@ -208,7 +205,6 @@ def django_instance_to_redis_params(
                 redis_root,
                 get_or_create_redis_model_from_django_model
             )
-            print(redis_param)
             redis_params[django_field.name] = redis_param
     return redis_params
 
