@@ -427,7 +427,10 @@ class RedisRoot:
                 django_models_to_cache[django_model] = cache_conf
                 ttl = cache_conf['ttl']
                 now = datetime.datetime.now()
-                self.registered_django_models[django_model] = now + datetime.timedelta(seconds=ttl)
+                self.registered_django_models[django_model] = {
+                    'to_cache_in': now + datetime.timedelta(seconds=ttl),
+                    'cache_conf': cache_conf
+                }
         return django_models_to_cache
 
     def check_cache(self):
@@ -555,7 +558,7 @@ class RedisRoot:
                 self,
                 get_or_create_redis_model_from_django_model
             )
-            print(django_model)
+            print(f'Cached {django_model}')
 
     def _get_connection_pool(self, connection_pool):
         if isinstance(connection_pool, redis.ConnectionPool):
